.. include:: ../BADGES.rst

.. _hspf_utils_documentation:

hspf_utils
==========

This is the home page for hspf_utils.  hspf_utils is a command line program and
Python library of utilities to work with the Hydrological Simulation Program
- FORTRAN (HSPF).

hspf_utils should work with Python 3.6+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   command_line
   function_summary
   contributing
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
